@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 # Copyright 2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from quodlibet.util.dprint import print_d, print_w
 from quodlibet.browsers.soundcloud.query import SoundcloudQuery
@@ -34,12 +34,11 @@ class SoundcloudLibrary(SongLibrary):
     def query_with_refresh(self, text, sort=None, star=STAR):
         """Queries Soundcloud for some (more) relevant results, then filters"""
         current = self._contents.values()
-        try:
-            query = SoundcloudQuery(text, star=star)
-            self.client.get_tracks(query.terms)
-        except SoundcloudQuery.error as e:
-            print_w("Couldn't filter for query '%s' (%s)" % (text, e))
+
+        query = SoundcloudQuery(text, star=star)
+        if not query.is_parsable:
             return current
+        self.client.get_tracks(query.terms)
         filtered = query.filter(current)
         print_d("Filtered %d results to %d" % (len(current), len(filtered)))
         return filtered
@@ -50,6 +49,7 @@ class SoundcloudLibrary(SongLibrary):
     def _on_songs_received(self, client, songs):
         new = len(self.add(songs))
         print_d("Got %d songs (%d new)." % (len(songs), new))
+        self.emit('changed', songs)
 
     def _on_comments_received(self, client, track_id, comments):
         def bookmark_for(com):
