@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2012,2013 Christoph Reiter
 #           2010-2017 Nick Boultbee
@@ -38,7 +37,7 @@ def main(argv=None):
     quodlibet.init()
 
     from quodlibet import app
-    from quodlibet.qltk import add_signal_watch, Icons
+    from quodlibet.qltk import add_signal_watch
     add_signal_watch(app.quit)
 
     import quodlibet.player
@@ -50,7 +49,8 @@ def main(argv=None):
     app.name = "Quod Libet"
     app.description = _("Music player and music library manager")
     app.id = "io.github.quodlibet.QuodLibet"
-    quodlibet.set_application_info(Icons.QUODLIBET, "quodlibet", app.name)
+    app.process_name = "quodlibet"
+    quodlibet.set_application_info(app)
 
     library_path = os.path.join(quodlibet.get_user_dir(), "songs")
 
@@ -74,7 +74,7 @@ def main(argv=None):
     app.player = player
 
     environ["PULSE_PROP_media.role"] = "music"
-    environ["PULSE_PROP_application.icon_name"] = Icons.QUODLIBET
+    environ["PULSE_PROP_application.icon_name"] = app.icon_name
 
     browsers.init()
 
@@ -118,6 +118,8 @@ def main(argv=None):
 
     from gi.repository import GLib
 
+    from quodlibet.commands import registry as cmd_registry, CommandError
+
     def exec_commands(*args):
         for cmd in cmds_todo:
             try:
@@ -149,7 +151,6 @@ def main(argv=None):
 
     from quodlibet.mmkeys import MMKeysHandler
     from quodlibet.remote import Remote, RemoteError
-    from quodlibet.commands import registry as cmd_registry, CommandError
     from quodlibet.qltk.tracker import SongTracker, FSInterface
     try:
         from quodlibet.qltk.dbus_ import DBusHandler
@@ -170,12 +171,14 @@ def main(argv=None):
     DBusHandler(player, library)
     tracker = SongTracker(library.librarian, player, window.playlist)
 
-    from quodlibet.qltk import session
-    session.init("quodlibet")
+    from quodlibet import session
+    session_client = session.init(app)
 
     quodlibet.enable_periodic_save(save_library=True)
 
-    if "start-playing" in startup_actions:
+    if ("start-playing" in startup_actions or
+            (config.getboolean("player", "restore_playing", False) and
+                config.getboolean("player", "is_playing", False))):
         player.paused = False
 
     if "start-hidden" in startup_actions:
@@ -209,4 +212,6 @@ def main(argv=None):
 
     config.save()
 
+    session_client.close()
+
     print_d("Finished shutdown.")
