@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2016 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
@@ -55,7 +54,7 @@ def build_shortcut_window(data):
 
     # Note: gtk+ is picky about the order of adding/showing things because
     # this is usually done through XML. e.g. adding shortcuts after a section
-    # wont make them show up in the search etc..
+    # won't make them show up in the search etc..
     w = Gtk.ShortcutsWindow()
     section = Gtk.ShortcutsSection()
     section.show()
@@ -94,6 +93,7 @@ def show_shortcuts(parent):
         # window placement. This fixes the jumping around and wrong position
         # with some WMs and under Windows.
         window.hide()
+        window.unrealize()
         window.show()
     else:
         util.website(const.SHORTCUTS_HELP)
