@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 # Copyright 2012-2013 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from __future__ import absolute_import
 
@@ -12,7 +12,6 @@ from collections import namedtuple
 
 from quodlibet.util.dprint import print_d, print_w
 from quodlibet.util.misc import total_ordering
-from quodlibet.compat import PY3
 
 
 @total_ordering
@@ -136,8 +135,7 @@ class JSONObjectDict(dict):
         except AttributeError:
             raise
         json_str = json.dumps(obj_dict, indent=4)
-        if PY3:
-            json_str = json_str.encode("utf-8")
+        json_str = json_str.encode("utf-8")
         if filename:
             try:
                 with open(filename, "wb") as f:
